@@ -2,19 +2,18 @@ from django.conf.urls.defaults import *
 
 from piston.resource import Resource
 
-from authentication import DjangoStaffAuthentication, DjangoUploadAuthentication
+from authentication import DjangoStaffAuthentication
 from handlers import PageHandler, PageContentItemHandler, ImageHandler, FileHandler, FileUploadHandler, ImageUploadHandler, ContentItemHandler
 from emitters import jqGridJSONEmitter
 
 auth = DjangoStaffAuthentication()
-upload_auth = DjangoUploadAuthentication()
 
 page_handler = Resource(PageHandler, authentication=auth)
 page_content_item_handler = Resource(PageContentItemHandler, authentication=auth)
 image_handler = Resource(ImageHandler, authentication=auth)
 file_handler = Resource(FileHandler, authentication=auth)
-file_upload_handler = Resource(FileUploadHandler, authentication=upload_auth)
-image_upload_handler = Resource(ImageUploadHandler, authentication=upload_auth)
+file_upload_handler = Resource(FileUploadHandler, authentication=auth)
+image_upload_handler = Resource(ImageUploadHandler, authentication=auth)
 content_item_handler = Resource(ContentItemHandler, authentication=auth)
 
 urlpatterns = patterns('',
